@@ -5,7 +5,7 @@ use warnings;
 use utf8;
 use Regexp::Grammars;
 
-our $VERSION = '1.071';
+our $VERSION = '2.001';
 
 sub new {
         my ($class) = @_;
@@ -1386,41 +1386,34 @@ HL is a programming language.
 =head1 EXAMPLE
 
     class Main {
-        (JSON,
-         !mechanize = WWW::Mechanize.new(),
-         !bloomFaster = Bloom::Faster.new({"m" : 1000000, "k" : 5}));
+    	(JSON,
+    	 !mechanize = WWW::Mechanize.new());
 
-        function main() {
-            class.counter = 0;
+    	function main() {
+    		class.counter = 0;
 
-            var hash = class.returnNumber();
-            var json = encode_json(hash);
-            print(json, "\n");
+    		var hash = class.returnNumber();
+    		var json = encode_json(hash);
+    		print(json, "\n");
 
-            var url = "https://metacpan.org/pod/WWW::Mechanize";
-            !mechanize.get(url);
-            var page = !mechanize.text();
-            print(page, "\n");
+    		var url = "https://metacpan.org/pod/WWW::Mechanize";
+    		!mechanize.get(url);
+    		var page = !mechanize.text();
+    		print(page, "\n");
+    	}
 
-            !bloomFaster.add(url);
-            var bool = !bloomFaster.check(url);
-            if(bool) {
-                print("Url present", "\n");
-            }
-        }
+    	function returnNumber() {
+    		var number = {};
 
-        function returnNumber() {
-            var number = {};
+    		if(class.counter < 10) {
+    			class.counter = class.counter + 1;
 
-            if(class.counter < 10) {
-                class.counter = class.counter + 1;
+    			number = { "number" : class.returnNumber() };
+    			return number;
+    		}
 
-                number = { "number" : class.returnNumber() };
-                return number;
-            }
-
-            return class.counter;
-        }
+    		return class.counter;
+    	}
     }
 
 =head1 AUTHOR
